@@ -1,4 +1,4 @@
-from .api_keys import configure_api_keys
 import scrapemm.common
+from .secrets import configure_secrets
 from .retrieval import retrieve
 from .integrations import Telegram, X
\ No newline at end of file
